==> liquidwar6-0.2.3551.tar.gz: liquidwar6-0.2.3551/src/lib/sim/sim-mask.c <==
/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.


  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "sim.h"
#include "sim-internal.h"

int
_lw6sim_mask_get_max (int nb_teams)
{
  int ret = 0;
  int i;

  for (i = 0; i < nb_teams; ++i)
    {
      ret |= lw6ker_team_mask_color2mask (i);
    }
  ret++;

  return ret;
}

int
_lw6sim_mask_is_valid (int mask)
{
  int ret = 0;
  int i;

  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
    {
      if (lw6ker_team_mask_is_concerned (i, mask))
	{
	  ret++;
	}
    }

  /*
   * We consider the mask is valid if there are at least two
   * teams playing.
   */
  ret = (ret >= 2);

  return ret;
}

==> liquidwar6-0.6.3902.tar.gz: liquidwar6-0.6.3902/src/lib/sim/sim-mask.c <==
/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.


  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "sim.h"
#include "sim-internal.h"

int
_lw6sim_mask_get_max (lw6sys_context_t * sys_context, int nb_teams)
{
  int ret = 0;
  int i;

  for (i = 0; i < nb_teams; ++i)
    {
      ret |= lw6ker_team_mask_color2mask (sys_context, i);
    }
  ret++;

  return ret;
}

int
_lw6sim_mask_is_valid (lw6sys_context_t * sys_context, int mask)
{
  int ret = 0;
  int i;

  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
    {
      if (lw6ker_team_mask_is_concerned (sys_context, i, mask))
	{
	  ret++;
	}
    }

  /*
   * We consider the mask is valid if there are at least two
   * teams playing.
   */
  ret = (ret >= 2);

  return ret;
}
